/**
 * Controller Task
 * This is the main task that is invoked for the processing of the slushfile.js
 */

(function() {
    var gulp = require('gulp'),
        install = require('gulp-install'),
        conflict = require('gulp-conflict'),
        template = require('gulp-template'),
        rename = require('gulp-rename'),
        inquirer = require('inquirer')
    _ = require('underscore.string');

    //Local dependencies
    var util = require('../util');

    module.exports = function(gulp) {
        'use strict';

        gulp.task('directive', function(done) {
            var _this = this;
            var name = util.getDefaultOption(_this.args, 0);
            var options = util.getGlobalOptions();
            var modules = util.getModuleProposal(options.appDir);

            if (modules.length === 0) {
                throw new Error('Directive must be created in a module, but no modules exist. Create a module using "slush angular-gulp:module <module-Name>".');
            }

            inquirer.prompt([{
                type: 'input',
                name: 'fileName',
                message: 'What is the name of your directive?',
                default: name
            }, {
                type: 'list',
                name: 'module',
                message: 'What is your AngularJS module name?',
                choices: modules
            }], function(answers) {
                //Init
                answers.nameDashed = _.slugify(util.getNameProposal());
                answers.scriptAppName = _.camelize(answers.nameDashed) + '.' + answers.module;
                answers.classedName = _.camelize(answers.fileName);
                answers.classedNameDashed = _.slugify(answers.fileName);

                //Source
                gulp.src(__dirname + '/../templates/directive/directive.js')
                    .pipe(template(answers))
                    .pipe(rename(answers.fileName + '-directive.js'))
                    .pipe(conflict(options.base + options.appDir + '/' + answers.module))
                    .pipe(gulp.dest(options.base + options.appDir + '/' + answers.module))
                    .on('finish', function() {
                        done();
                    });
            });
        });
    }
})();
